EventSourceTask

Struct EventSourceTask 

pub struct EventSourceTask { /* private fields */ }
A handle to control current event source connection. Implements Task and could be canceled.

Implementations

Source

impl EventSourceTask

pub fn add_event_listener<S, OUT>( &mut self, event_type: S, callback: Callback<OUT>, )
where S: Into<Cow<'static, str>>, OUT: From<Text> + 'static,

Register a callback for events of a given type

This registers an event listener, which will fire callback when an event of event_type occurs.

pub fn ready_state(&self) -> ReadyState

Query the ready state of the event source.